==> adhesion.1.1.zip: adhesion/lang/fr.php <==
<?php

$LANG                              = array(

'L_PAGE_TITLE'                     => 'Devenir membre',

# config.php
'L_MAIL_AVAILABLE'                 => 'Fonction d\'envoi de mail disponible',
'L_MAIL_NOT_AVAILABLE'             => 'Fonction d\'envoi de mail non disponible',

'L_CONFIG_ROOT_PATH'               => 'Emplacement du fichier des adherents (fichier xml)',
'L_MENU_DISPLAY'                   => 'Afficher le menu de la page d\'adhésion',
'L_MENU_TITLE'                     => 'Titre du menu',
'L_MENU_FORGET_PASS'               => 'Titre de la page de récupération du mot de passe',
'L_MENU_MY_ACCOUNT'                => 'Titre de la page du compte adhérent',
'L_MENU_POS'                       => 'Position du menu',
'L_EMAIL'                          => 'Adresse email',
'L_EMAIL_SUBJECT'                  => 'Objet du mail',
'L_PASSWD_SUBJECT'                 => 'Objet du mail de récupération du mot de passe',
'L_PASSWD_MESSAGE'                 => 'Message de récupération du mot de passe',
'L_THANKYOU_MESSAGE'               => 'Message de remerciement',
'L_TEMPLATE'                       => 'Template',
'L_SAVE'                           => 'Enregistrer',
'L_ADRESSE_ASSO'                   => 'Adresse de l\'association',
'L_CLE'                            => 'Longueur de la clé du mot de passe',
'L_ANNEE'                          => 'Type d\'année pour la durée de l\'adhésion',
'L_ANNEE_CIVILE'                   => 'Année civile',
'L_ANNEE_ENTIERE'                  => 'Année entière',
'L_NOM_ASSO'                       => 'Nom de l\'association',
'L_DOMAINE_ASSO'                   => 'Nom de domaine du site (style : asso.com)',

'L_DEFAULT_MENU_NAME'              => 'Devenir membre',
'L_DEFAULT_MENU_PASS'              => 'Récupération du mot de passe',
'L_DEFAULT_MENU_MY_ACCOUNT'        => 'Mon compte',
'L_DEFAULT_SUBJECT'                => '## NOM ASSOCIATON ## Nouvelle demande d\'adhésion',
'L_DEFAULT_SUBJECT_PASS'           => '## NOM ASSOCIATON ## Récupération de votre mot de passe',
'L_DEFAULT_MSG_PASS'               => 'Vous avez demandé à récupérer votre mot de passe. Les informations de connexion sont les suivantes :',
'L_DEFAULT_THANKYOU'               => 'Merci pour votre demande d\'adhésion. Elle ne sera validée que lors de la réception de votre paiement (xxxx euros) par le trésorier de l\'association.',
'L_DEFAULT_VAL_SUB'                => '## NOM ASSOCIATON ## Demande d\'adhésion validée',
'L_DEFAULT_VAL_MSG'                => 'Merci pour votre demande d\'adhésion. Nous venons de recevoir votre paiement et nous vous informons que vous êtes officiellement inscrit.',
'L_DEFAULT_DEVAL_SUB'              => '## NOM ASSOCIATON ## Demande de désinscription validée',
'L_DEFAULT_DEVAL_MSG'              => 'Nous vous informons que vous n\'êtes plus adhérent. Si vous souhaitez renouveler votre adhésion, merci d\'adresser votre règlement au trésorier de l\'association.',
'L_WARNING_SUBJECT'                => 'Pensez à modifier l\'objet du message d\'adhésion',
'L_WARNING_DEVAL_SUBJECT'          => 'Pensez à modifier l\'objet du message de dévalidation',
'L_WARNING_VAL_SUBJECT'            => 'Pensez à modifier l\'objet du message de validation de l\'adhésion',
'L_WARNING_PASS'                   => 'Pensez à modifier le sujet de récupération du mot de passe',
'L_WARNING_THANKYOU'               => 'Pensez à modifier le message de remerciement',
'L_WARNING_NAME_ASSO'              => 'Veuillez renseigner un nom d\'association',
'L_WARNING_ADDRESS_ASSO'           => 'Veuillez renseigner une adresse pour l\'association',


# bulletin adhesion
'L_FORM_ALL_REQUIRED'              => 'Tous les champs sont requis',
'L_FORM_IDENTITY'                  => 'Identité',
'L_FORM_NAME'                      => 'Nom',
'L_FORM_FIRST_NAME'                => 'Prénom',
'L_FORM_MAIL'                      => 'Email (important)',
'L_FORM_OTHER'                     => 'Autre',
'L_FORM_DETAIL'                    => 'Précisez',
'L_FORM_CHOICE'                    => 'Votre choix',
'L_FORM_SHARING'                   => 'Partage de vos données',
'L_FORM_MAILING'                   => 'Des nouvelles de l\'association',
'L_FORM_ACTIVITY'                  => 'Activité',
'L_FORM_AGENDA'                    => 'Coordonnées',
'L_FORM_SOCIETY'                   => 'Etablissement',
'L_FORM_SERVICE'                   => 'Service',
'L_FORM_ADDRESS'                   => 'Adresse',
'L_FORM_ZIP_CODE'                  => 'Code Postal',
'L_FORM_CITY'                      => 'Ville',
'L_FORM_TEL'                       => 'Téléphone',
'L_FORM_BTN_SEND'                  => 'Envoyer',
'L_FORM_ANTISPAM'                  => 'Vérification anti-spam',
'L_FORM_ERASE'                     => 'Votre demande de désinscription a bien été prise en compte. N\'hésitez pas à nous rejoindre si vous changez d\'avis',
'L_FORM_ERASE_OK'                  => 'Désinscription enregistrée.',
'L_FORM_ERASE_FORM_LIST_OK'        => 'Désinscription des listes de diffusion enregistrée.',
'L_ALREADY_REC'                    => 'Les modifications ont bien été prises en compte.',
'L_FORM_MEMBERS'                   => 'Espace membres',
'L_FORM_OK'                        => 'OK',
'L_FORGET_PASS'                    => 'Mot de passe oublié ?',
'L_MY_ACCOUNT'                     => 'Paramétrer mon compte',
'L_EMAIL_PASS_OK'                  => 'Un mail vient de vous être envoyé avec votre mot de passe.',
'L_EMAIL_PASS_KO'                  => 'Une erreur est survenue. Merci d\'utiliser le formulaire de contact',
'L_FORM_EMPTY'                     => 'Un ou plusieurs champs n\'ont pas été convenablement complétés :',
'L_EDIT_OK'                        => 'Les modifications ont été enregistrées',
'L_DEVAL_OK'                       => 'Vous n\'êtes plus membre de l\'association',
'L_FORM_CONFIRM'                   => 'Êtes-vous sûr de ne plus vouloir être membre de l\'association ? Cette action est irréversible.',

# erreurs
'L_ERR_REC'                        => 'Les donnés n\'ont pas été correctement enregistrées.',
'L_ERR_NAME'                       => 'Le nom',
'L_ERR_FIRST_NAME'                 => 'Le prénom',
'L_ERR_ACTIVITE'                   => 'L\'activité',
'L_ERR_AUTRE_ACTIVITE'             => 'L\'intitulé de votre activité',
'L_ERR_ETABLISSEMENT'              => 'L\'établissement',
'L_ERR_SERVICE'                    => 'Le service',
'L_ERR_ADRESSE'                    => 'L\'adresse',
'L_ERR_CP'                         => 'Le code postal',
'L_ERR_VILLE'                      => 'La ville',
'L_ERR_TEL'                        => 'Le téléphone',
'L_ERR_CHOIX'                      => 'Votre choix',
'L_ERR_COORDONNEES'                => 'Le traitement de vos données',
'L_ERR_MAILING'                    => 'Les informations sur l\'AARCH',
'L_ERR_MAIL'                       => 'L\'adresse e-mail',
'L_ERR_ANTISPAM'                   => 'La vérification anti-spam',
'L_FORM_THANKYOU'                  => 'Merci pour votre demande.',
'L_MSG_WELCOME'                    => 'Merci de remplir le formulaire ci-dessous',
'L_ERR_EMAIL'                      => 'Veuillez saisir une adresse email valide',
'L_ERR_ANTISPAM'                   => 'La vérification anti-spam a échoué',
'L_ERR_SENDMAIL'                   => 'Une erreur est survenue pendant l\'envoi de votre message',
'L_ERR_FILE_ADHERENTS'             => 'Le chemin vers le fichier des adhérents doit être complété.',
'L_ERR_USER_ALREADY_USED'          => 'Cet adhérent existe déjà',
'L_ERR_USER_ALREADY_VALID'         => 'Votre compte est encore valide',
'L_ERR_NO_LIST'                    => 'Il n\'y a pas de liste de diffusion disponible. Veuillez désactiver puis réactiver le plugin',
'L_ERR_sendEmail'                  => 'Echec de l\'envoi du mail de confirmation',
'L_ERR_NO_GUTUMA'                  => 'Le plugin adhésion nécessite le plugin <a href=\"http://www.ecyseo.net/\" title=\"Voir page téléchargements\" onclick=\"window.open(this.href);return false;\">Gutuma</a> pour fonctionner. Ce dernier doit être activé.',
'L_INTERNAL_ERR'                   => 'Échec de l\'enregistrement : erreur interne',

# admin
'L_TITLE_CONFIG'                   => 'Page d\'administration des adhérents',
'L_ADMIN_LIST_MEMBERS_TO_VALIDATE' => 'Liste des adhérents à valider',
'L_ADMIN_LIST_MEMBERS_VALIDATED'   => 'Liste des adhérents validés',
'L_ADMIN_LIST_MEMBERS_VALIDE'      => 'Liste des adhérents validés',
'L_ADMIN_LIST_ID'                  => 'ID',
'L_ADMIN_FIRST_ASK'                => '1ere inscript&deg;',
'L_ADMIN_DATE_VAL'                 => 'Validé le',
'L_ADMIN_LIST_NAME'                => 'Nom',
'L_ADMIN_LIST_FIRST_NAME'          => 'Prénom',
'L_ADMIN_LIST_ACTIVITY'            => 'Activité',
'L_ADMIN_LIST_STRUCTURE'           => 'Etablissement',
'L_ADMIN_LIST_DPT'                 => 'Service',
'L_ADMIN_LIST_ADRESSE'             => 'Adresse',
'L_ADMIN_LIST_ZIP_CODE'            => 'Code Postal',
'L_ADMIN_LIST_CITY'                => 'Ville',
'L_ADMIN_LIST_TEL'                 => 'Téléphone',
'L_ADMIN_LIST_MAIL'                => 'Email',
'L_ADMIN_LIST_CHOICE'              => 'Choix',
'L_ADMIN_LIST_COORDONNEES'         => 'Partage',
'L_ADMIN_LIST_MAILING'             => 'Newsletters',
'L_ADMIN_LIST_VALIDATION'          => 'Valider',
'L_ADMIN_LIST_UPDATE'              => 'Mettre à jour',
'L_ADMIN_LIST_DEVALIDATION'        => 'Dévalider',
'L_ADMIN_LIST_NEW'                 => 'Nouveau membre',
'L_ADMIN_APPLY_BUTTON'             => 'Enregistrer',
'L_ADMIN_SELECTION'                => 'Pour la sélection',
'L_ADMIN_DELETE'                   => 'Effacer',
'L_ADMIN_VALIDATION_PENDING'       => 'Il n\'y a pas de demande d\'adhésion en attente de validation',
'L_ADMIN_NO_VALIDATION'            => 'Il n\'y a pas d\'adhésion validatée',
'L_VALIDATION_SUBJECT'             => 'Objet du mail de validation',
'L_VALIDATION_MESSAGE'             => 'Message du mail de validation',
'L_DEVALIDATION_SUBJECT'           => 'Objet du mail de dévalidation',
'L_DEVALIDATION_MESSAGE'           => 'Message du mail de dévalidation',
'L_ADMIN_ADD_ADD'                  => 'Adresse(s) ajoutée(s) à la liste de diffusion',
'L_ADMIN_REMOVE_ADD'               => 'Adresse(s) retirée(s) de la liste de diffusion',
'L_ADMIN_REMOVE_ADH'               => 'Fiche(s) adhérent(s) supprimée(s)',
'L_ADMIN_UPDATE_ADH'               => 'Fiche(s) adhérent(s) modifiée(s)',
'L_ADMIN_NEW_ADH'                  => 'Fiche(s) adhérent(s) ajoutée(s)',
'L_ADMIN_VALIDATION_ADH'           => 'Fiche(s) adhérent(s) validée(s)',
'L_ADMIN_DEVALIDATION_ADH'         => 'Fiche(s) adhérent(s) désactivée(s)',
'L_FORM_NEW'                       => 'Nouvelle demande',
'L_ADMIN_DATE_DEL'                 => 'Dévalidé le',
'L_ADMIN_LIST_CLE'                 => 'Clef d\'activation',
'L_ADMIN_PASSWORD'                 => 'Votre mot de passe est :',

# LookArticles
'L_HIDE_LOCKED_ARTICLES'           =>	'Masquer les articles protégés par un mot de passe de la home page',
'L_HIDE_LOCKED_CATEGORIES'         =>	'Masquer les articles des catégories protégées de la home page',
'L_SAVE'                           =>	'Sauvegarder',
'L_ARTICLE_PASSWORD_FIELD_LABEL'   =>	'Cet article doit-il être protégé par un mot de passe ?',
'L_PLUGIN_BAD_PASSWORD'            =>	'Mauvais mot de passe',
'L_PLUGIN_GOOD_PASSWORD'           =>	'Vous êtes connecté(e)',
'L_PLUGIN_EXPIRED_PASSWORD'        =>	'Mot de passe expir&eacute;',
'L_CATEGORIE_PASSWORD_FIELD_LABEL' =>	'Cette catégorie doit-elle être protégée par un mot de passe ?',
'L_FORM_LOGOUT'                    => 	'Déconnexion',
'L_FORM_PASSWORD'                  =>	'Mot de passe',
'L_FORM_ADMIN_PASSWORD'            =>	'Cette page statique doit-elle être protégée par un mot de passe ?',
'L_FORM_OK'                        =>	'ok',
'L_CONNEXION_OK'                   =>	'Vous êtes connecté',
'L_DECONNEXION_OK'                 =>	'Vous êtes déconnecté',
'L_NEED_AUTH'                      =>   'Vous devez vous connecter pour pouvoir accéder à cet article',
);
?>

==> adhesion.1.2.zip: adhesion/lang/fr.php <==
<?php

$LANG                              = array(

'L_PAGE_TITLE'                     => 'Devenir membre',
'L_ID'                             => 'Identifiant',

# config.php
'L_MAIL_AVAILABLE'                 => 'Fonction d\'envoi de mail disponible',
'L_MAIL_NOT_AVAILABLE'             => 'Fonction d\'envoi de mail non disponible',
'L_ART_PROTECTED'                  => 'Article protégé par mot de passe',
'L_CAT_PROTECTED'                  => 'Catégorie protégée par mot de passe',

'L_CONFIG_ROOT_PATH'               => 'Emplacement du fichier des adherents (fichier xml)',
'L_MENU_DISPLAY'                   => 'Afficher le menu de la page d\'adhésion',
'L_MENU_TITLE'                     => 'Titre du menu principal',
'L_MENU_ADHERER_TITLE'             => 'Titre du menu d\'adhésion',
'L_MENU_DESC'                      => 'Description de l\'adhésion',
'L_MENU_FORGET_PASS'               => 'Titre de la page de récupération du mot de passe',
'L_MENU_MY_ACCOUNT'                => 'Titre de la page du compte adhérent',
'L_SHOW_MENU_ANNUAIRE'             => 'Afficher l\'annuaire',
'L_MENU_ANNUAIRE'                  => 'Titre de la page annuaire',
'L_ANNUAIRE_GEN'                   => 'Généraliste',
'L_ANNUAIRE_PRO'                   => 'Professionel',
'L_TYPE_ANNUAIRE'                  => 'Type d\'annuaire',
'L_MENU_POS'                       => 'Position du menu',
'L_EMAIL'                          => 'Adresse email',
'L_EMAIL_SUBJECT'                  => 'Objet du mail',
'L_PASSWD_SUBJECT'                 => 'Objet du mail de récupération du mot de passe',
'L_PASSWD_MESSAGE'                 => 'Message de récupération du mot de passe',
'L_THANKYOU_MESSAGE'               => 'Message de remerciement',
'L_TEMPLATE'                       => 'Template',
'L_SAVE'                           => 'Enregistrer',
'L_ADRESSE_ASSO'                   => 'Adresse de l\'association',
'L_CLE'                            => 'Longueur de la clé du mot de passe',
'L_ANNEE'                          => 'Type d\'année pour la durée de l\'adhésion',
'L_ANNEE_CIVILE'                   => 'Année civile',
'L_ANNEE_ENTIERE'                  => 'Année entière',
'L_NOM_ASSO'                       => 'Nom de l\'association',
'L_DOMAINE_ASSO'                   => 'Nom de domaine du site (style : asso.com)',

'L_DEFAULT_MENU_NAME'              => 'Devenir membre',
'L_DEFAULT_MENU_ADHERER'           => 'Adhérer à l\'association',
'L_DEFAULT_DESC'                   => 'Placer ici ce que l\'association peut apporter aux adhérents',
'L_DEFAULT_MENU_PASS'              => 'Récupération du mot de passe',
'L_DEFAULT_MENU_MY_ACCOUNT'        => 'Mon compte',
'L_DEFAULT_MENU_ANNUAIRE'          => 'Annuaire des membres',
'L_DEFAULT_SUBJECT'                => '## NOM ASSOCIATON ## Nouvelle demande d\'adhésion',
'L_DEFAULT_SUBJECT_PASS'           => '## NOM ASSOCIATON ## Récupération de votre mot de passe',
'L_DEFAULT_MSG_PASS'               => 'Vous avez demandé à récupérer votre mot de passe. Les informations de connexion sont les suivantes :',
'L_DEFAULT_THANKYOU'               => 'Merci pour votre demande d\'adhésion. Elle ne sera validée que lors de la réception de votre paiement (xxxx euros) par le trésorier de l\'association.',
'L_DEFAULT_VAL_SUB'                => '## NOM ASSOCIATON ## Demande d\'adhésion validée',
'L_DEFAULT_VAL_MSG'                => 'Merci pour votre demande d\'adhésion. Nous venons de recevoir votre paiement et nous vous informons que vous êtes officiellement inscrit.',
'L_DEFAULT_DEVAL_SUB'              => '## NOM ASSOCIATON ## Demande de désinscription validée',
'L_DEFAULT_DEVAL_MSG'              => 'Nous vous informons que vous n\'êtes plus adhérent. Si vous souhaitez renouveler votre adhésion, merci d\'adresser votre règlement au trésorier de l\'association.',
'L_WARNING_SUBJECT'                => 'Pensez à modifier l\'objet du message d\'adhésion',
'L_WARNING_DEVAL_SUBJECT'          => 'Pensez à modifier l\'objet du message de dévalidation',
'L_WARNING_VAL_SUBJECT'            => 'Pensez à modifier l\'objet du message de validation de l\'adhésion',
'L_WARNING_PASS'                   => 'Pensez à modifier le sujet de récupération du mot de passe',
'L_WARNING_THANKYOU'               => 'Pensez à modifier le message de remerciement',
'L_WARNING_NAME_ASSO'              => 'Veuillez renseigner un nom d\'association',
'L_WARNING_ADDRESS_ASSO'           => 'Veuillez renseigner une adresse pour l\'association',
'L_WARNING_DESC'                   => 'Veuillez expliquer ce que l’association apporte aux adherents',


# bulletin adhesion
'L_FORM_ALL_REQUIRED'              => 'Tous les champs sont requis',
'L_FORM_IDENTITY'                  => 'Identité',
'L_FORM_NAME'                      => 'Nom',
'L_FORM_FIRST_NAME'                => 'Prénom',
'L_FORM_MAIL'                      => 'Email (important)',
'L_FORM_OTHER'                     => 'Autre',
'L_FORM_DETAIL'                    => 'Précisez',
'L_FORM_CHOICE'                    => 'Votre choix',
'L_FORM_SHARING'                   => 'Partage de vos données',
'L_FORM_MAILING'                   => 'Des nouvelles de l\'association',
'L_FORM_ACTIVITY'                  => 'Activité',
'L_FORM_AGENDA'                    => 'Coordonnées',
'L_FORM_SOCIETY'                   => 'Etablissement',
'L_FORM_SERVICE'                   => 'Service',
'L_FORM_ADDRESS'                   => 'Adresse',
'L_FORM_ZIP_CODE'                  => 'Code Postal',
'L_FORM_CITY'                      => 'Ville',
'L_FORM_TEL'                       => 'Téléphone',
'L_FORM_TEL_OFFICE'                => 'Téléphone professionel ou poste',
'L_FORM_BTN_SEND'                  => 'Envoyer',
'L_FORM_ANTISPAM'                  => 'Vérification anti-spam',
'L_FORM_ERASE'                     => 'Votre demande de désinscription a bien été prise en compte. N\'hésitez pas à nous rejoindre si vous changez d\'avis',
'L_FORM_ERASE_OK'                  => 'Désinscription enregistrée.',
'L_FORM_ERASE_FORM_LIST_OK'        => 'Désinscription des listes de diffusion enregistrée.',
'L_ALREADY_REC'                    => 'Les modifications ont bien été prises en compte.',
'L_FORM_MEMBERS'                   => 'Espace membres',
'L_FORM_OK'                        => 'OK',
'L_FORGET_PASS'                    => 'Mot de passe oublié ?',
'L_MY_ACCOUNT'                     => 'Paramétrer mon compte',
'L_EMAIL_PASS_OK'                  => 'Un mail vient de vous être envoyé avec votre mot de passe.',
'L_EMAIL_PASS_KO'                  => 'Une erreur est survenue. Merci d\'utiliser le formulaire de contact',
'L_FORM_EMPTY'                     => 'Un ou plusieurs champs n\'ont pas été convenablement complétés :',
'L_EDIT_OK'                        => 'Les modifications ont été enregistrées',
'L_DEVAL_OK'                       => 'Vous n\'êtes plus membre de l\'association',
'L_FORM_CONFIRM'                   => 'Êtes-vous sûr de ne plus vouloir être membre de l\\\'association ? Cette action est irréversible.',

# erreurs
'L_ERR_REC'                        => 'Les donnés n\'ont pas été correctement enregistrées.',
'L_ERR_NAME'                       => 'Le nom',
'L_ERR_FIRST_NAME'                 => 'Le prénom',
'L_ERR_ACTIVITE'                   => 'L\'activité',
'L_ERR_AUTRE_ACTIVITE'             => 'L\'intitulé de votre activité',
'L_ERR_ETABLISSEMENT'              => 'L\'établissement',
'L_ERR_SERVICE'                    => 'Le service',
'L_ERR_ADRESSE'                    => 'L\'adresse',
'L_ERR_CP'                         => 'Le code postal',
'L_ERR_VILLE'                      => 'La ville',
'L_ERR_TEL'                        => 'Le téléphone',
'L_ERR_CHOIX'                      => 'Votre choix',
'L_ERR_COORDONNEES'                => 'Le traitement de vos données',
'L_ERR_MAILING'                    => 'Les informations sur l\'AARCH',
'L_ERR_MAIL'                       => 'L\'adresse e-mail',
'L_ERR_ANTISPAM'                   => 'La vérification anti-spam',
'L_FORM_THANKYOU'                  => 'Merci pour votre demande.',
'L_MSG_WELCOME'                    => 'Merci de remplir le formulaire ci-dessous',
'L_ERR_EMAIL'                      => 'Veuillez saisir une adresse email valide',
'L_ERR_ANTISPAM'                   => 'La vérification anti-spam a échoué',
'L_ERR_SENDMAIL'                   => 'Une erreur est survenue pendant l\'envoi de votre message',
'L_ERR_FILE_ADHERENTS'             => 'Le chemin vers le fichier des adhérents doit être complété.',
'L_ERR_USER_ALREADY_USED'          => 'Cet adhérent existe déjà',
'L_ERR_USER_ALREADY_VALID'         => 'Votre compte est encore valide',
'L_ERR_NO_LIST'                    => 'Il n\'y a pas de liste de diffusion disponible. Veuillez désactiver puis réactiver le plugin',
'L_ERR_sendEmail'                  => 'Echec de l\'envoi du mail de confirmation',
'L_ERR_NO_GUTUMA'                  => 'Le plugin adhésion nécessite le plugin <a href=\"http://www.ecyseo.net/\" title=\"Voir page téléchargements\" onclick=\"window.open(this.href);return false;\">Gutuma</a> pour fonctionner. Ce dernier doit être activé.',
'L_INTERNAL_ERR'                   => 'Échec de l\'enregistrement : erreur interne',

# admin
'L_TITLE_CONFIG'                   => 'Page d\'administration des adhérents',
'L_ADMIN_LIST_MEMBERS_TO_VALIDATE' => 'Liste des adhérents à valider',
'L_ADMIN_LIST_MEMBERS_VALIDATED'   => 'Liste des adhérents validés',
'L_ADMIN_LIST_MEMBERS_VALIDE'      => 'Liste des adhérents validés',
'L_ADMIN_LIST_ID'                  => 'ID',
'L_ADMIN_FIRST_ASK'                => 'Inscrit depuis le ',
'L_ADMIN_DATE_VAL'                 => 'Validé le',
'L_ADMIN_LIST_NAME'                => 'Nom',
'L_ADMIN_LIST_FIRST_NAME'          => 'Prénom',
'L_ADMIN_LIST_ACTIVITY'            => 'Activité',
'L_ADMIN_LIST_STRUCTURE'           => 'Etablissement',
'L_ADMIN_LIST_DPT'                 => 'Service',
'L_ADMIN_LIST_ADRESSE'             => 'Adresse',
'L_ADMIN_LIST_ZIP_CODE'            => 'Code Postal',
'L_ADMIN_LIST_CITY'                => 'Ville',
'L_ADMIN_LIST_TEL'                 => 'Téléphone',
'L_ADMIN_LIST_TEL_PRO'             => 'Téléphone professionel',
'L_ADMIN_LIST_TEL_OFFICE'          => 'Poste',
'L_ADMIN_LIST_MAIL'                => 'Email',
'L_ADMIN_LIST_CHOICE'              => 'Choix',
'L_ADMIN_LIST_COORDONNEES'         => 'Partage',
'L_ADMIN_LIST_MAILING'             => 'Newsletters',
'L_ADMIN_LIST_VALIDATION'          => 'Valider',
'L_ADMIN_LIST_UPDATE'              => 'Mettre à jour',
'L_ADMIN_LIST_DEVALIDATION'        => 'Dévalider',
'L_ADMIN_LIST_NEW'                 => 'Nouveau membre',
'L_ADMIN_APPLY_BUTTON'             => 'Enregistrer',
'L_ADMIN_SELECTION'                => 'Pour la sélection',
'L_ADMIN_DELETE'                   => 'Effacer',
'L_ADMIN_VALIDATION_PENDING'       => 'Il n\'y a pas de demande d\'adhésion en attente de validation',
'L_ADMIN_NO_VALIDATION'            => 'Il n\'y a pas d\'adhésion validatée',
'L_VALIDATION_SUBJECT'             => 'Objet du mail de validation',
'L_VALIDATION_MESSAGE'             => 'Message du mail de validation',
'L_DEVALIDATION_SUBJECT'           => 'Objet du mail de dévalidation',
'L_DEVALIDATION_MESSAGE'           => 'Message du mail de dévalidation',
'L_ADMIN_ADD_ADD'                  => 'Adresse(s) ajoutée(s) à la liste de diffusion',
'L_ADMIN_REMOVE_ADD'               => 'Adresse(s) retirée(s) de la liste de diffusion',
'L_ADMIN_REMOVE_ADH'               => 'Fiche(s) adhérent(s) supprimée(s)',
'L_ADMIN_UPDATE_ADH'               => 'Fiche(s) adhérent(s) modifiée(s)',
'L_ADMIN_NEW_ADH'                  => 'Fiche(s) adhérent(s) ajoutée(s)',
'L_ADMIN_VALIDATION_ADH'           => 'Fiche(s) adhérent(s) validée(s)',
'L_ADMIN_DEVALIDATION_ADH'         => 'Fiche(s) adhérent(s) désactivée(s)',
'L_FORM_NEW'                       => 'Nouvelle demande',
'L_ADMIN_DATE_DEL'                 => 'Dévalidé le',
'L_ADMIN_LIST_CLE'                 => 'Clef d\'activation',
'L_ADMIN_PASSWORD'                 => 'Votre mot de passe est :',
'L_ADMIN_ID'                       => 'Votre identifiant est votre nom relié à votre prénom, le tout en minuscules, sans espace, sans caractère accentué ou exotique comme les cédilles, les tirets, etc. (exemple : dupondjeanfrancois).',
'L_ADMIN_CONFIRM'                  => 'Êtes-vous sûr de vouloir supprimer cet adhérent ? Cette action est irréversible !',
'L_ADMIN_NOT_DONE'                 => 'Non renseignée',
'L_TAB_ACTIVITIES'                 => 'Quelles sont les activités possible ?',
'L_LABEL_FIND'                     => 'Rechercher adhérent',
'L_LABEL_DELETE_FILTER'            => 'Supprimer le filtre',

# LookArticles
'L_HIDE_LOCKED_ARTICLES'           =>	'Masquer les articles protégés par un mot de passe de la home page',
'L_HIDE_LOCKED_CATEGORIES'         =>	'Masquer les articles des catégories protégées de la home page',
'L_SAVE'                           =>	'Sauvegarder',
'L_ARTICLE_PASSWORD_FIELD_LABEL'   =>	'Cet article doit-il être protégé par un mot de passe ?',
'L_PLUGIN_BAD_PASSWORD'            =>	'Mauvais mot de passe',
'L_PLUGIN_MAXTRY'                  =>	'Nombre de tentatives dépassées. Vous pourrez tenter de vous reconnecter à partir de',
'L_PLUGIN_GOOD_PASSWORD'           =>	'Vous êtes connecté(e)',
'L_PLUGIN_EXPIRED_PASSWORD'        =>	'Mot de passe expir&eacute;',
'L_CATEGORIE_PASSWORD_FIELD_LABEL' =>	'Cette catégorie doit-elle être protégée par un mot de passe ?',
'L_FORM_LOGOUT'                    => 	'Déconnexion',
'L_FORM_PASSWORD'                  =>	'Mot de passe',
'L_FORM_ADMIN_PASSWORD'            =>	'Cette page statique doit-elle être protégée par un mot de passe ?',
'L_FORM_OK'                        =>	'ok',
'L_CONNEXION_OK'                   =>	'Vous êtes connecté',
'L_DECONNEXION_OK'                 =>	'Vous êtes déconnecté',
'L_NEED_AUTH'                      =>   'Vous devez vous connecter pour pouvoir accéder à cet article',
);
?>
